Module: Math::GraphTheory
- Defined in:
- lib/ruuuby/math/graph_theory/graph_theory.rb
Overview
‣ ‘Four Color Theorem` | “any map is 4-colorable and so one only needs four different colors to assure that no 2 states or countries w/ the same color share a border” ‣ graphs can be represented w/ Matrices (as long as each there does not exceed a single edge from one vertex to another in the same direction)