Module: Ruuuby::Feature::Includable::StringF09

Included in:
String
Defined in:
lib/ruuuby/class/str/str.rb

Overview

defines the operations needed to support Feature(f09) that are applied to Class(String)

Instance Method Summary collapse

Instance Method Details

#∈?(them) ⇒ Boolean

Returns true, if this string instance is contained in the provided str (or array/set).

Parameters:

Returns:

  • true, if this string instance is contained in the provided str (or array/set)

Raises:



164
165
166
167
# File 'lib/ruuuby/class/str/str.rb', line 164

def 

#∉?(them) ⇒ Boolean

Returns true, if this string instance is not contained in the provided str (or array/set).

Parameters:

Returns:

  • true, if this string instance is not contained in the provided str (or array/set)

Raises:



154
155
156
157
# File 'lib/ruuuby/class/str/str.rb', line 154

def 

#∋?(them) ⇒ Boolean

Returns true, if this string instance contains the provided str.

Parameters:

Returns:

  • true, if this string instance contains the provided str

Raises:



140
# File 'lib/ruuuby/class/str/str.rb', line 140

def 

#∌?(them) ⇒ Boolean

Returns true, if this string instance contains the provided str.

Parameters:

Returns:

  • true, if this string instance contains the provided str

Raises:



147
# File 'lib/ruuuby/class/str/str.rb', line 147

def